@@ -80,7 +80,7 @@ class RedisCache(BaseCache):
             return self.client.get(key, default=default, version=version,
                                    client=client)
         except ConnectionInterrupted as e:
-            if DJANGO_REDIS_IGNORE_EXCEPTIONS or self._ignore_exceptions:
+            if self._ignore_exceptions:
                 if DJANGO_REDIS_LOG_IGNORED_EXCEPTIONS:
                     logger.error(str(e))
                 return default
@@ -150,3 +150,7 @@ class RedisCache(BaseCache):
     @omit_exception
     def close(self, **kwargs):
         self.client.close(**kwargs)
+
+    @omit_exception
+    def touch(self, key, timeout=None, version=None):
+        return self.client.touch(key, timeout=timeout, version=version)
