@@ -14,8 +14,8 @@ CACHES = {
     'doesnotexist': {
         'BACKEND': 'django_redis.cache.RedisCache',
         'LOCATION': [
-            '127.0.0.1:56379:1',
-            '127.0.0.1:56379:2',
+            "redis://127.0.0.1:56379?db=1",
+            "redis://127.0.0.1:56379?db=2",
         ],
         'OPTIONS': {
             'CLIENT_CLASS': 'django_redis.client.ShardClient',
